@@ -1,12 +1,13 @@
 /* ====================================================================
- * Copyright (c) 1999-2000 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1999-2003 Ralf S. Engelschall <rse@engelschall.com>
+ * Copyright (c) 1999-2003 The OSSP Project <http://www.ossp.org/>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -62,7 +63,7 @@ extern "C" {
 #include <sys/types.h>
 #include <sys/stat.h>
 
-typedef enum { 
+typedef enum {
     MM_LOCK_RD, MM_LOCK_RW
 } mm_lock_mode;
 
@@ -72,7 +73,7 @@ typedef enum {
 
 #if defined(MM_PRIVATE)
 
-#include "mm_conf.h"
+#include "config.h"
 
 #include <errno.h>
 #include <limits.h>
@@ -80,6 +81,9 @@ typedef enum {
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
 
 #ifdef MM_OS_SUNOS
 #include <memory.h>
@@ -116,7 +120,7 @@ extern char *strerror(int);
 #define offset_of(type,member) ((size_t)(&((type *)0)->member))
 #endif
 
-#if !defined(HAVE_MEMCPY) 
+#if !defined(HAVE_MEMCPY)
 #if defined(HAVE_BCOPY)
 #define memcpy(to,from,len) bcopy(from,to,len)
 #else
@@ -132,7 +136,7 @@ extern char *strerror(int);
 #define ERR(type,str)   mm_lib_error_set(type,str)
 #define FAIL(type,str)  { ERR(type,str); goto cus; }
 #define BEGIN_FAILURE   cus:
-#define END_FAILURE   
+#define END_FAILURE
 
 #if defined(HAVE_PATH_MAX)
 #define MM_MAXPATH PATH_MAX
@@ -172,7 +176,7 @@ extern char *strerror(int);
 #define KERNEL 1
 #endif
 #ifdef MM_OS_BS2000
-#define _KMEMUSER 
+#define _KMEMUSER
 #endif
 #include <sys/shm.h>
 #ifdef MM_OS_SUNOS
@@ -208,7 +212,7 @@ union semun {
 #include <sys/file.h>
 #endif
 
-#define MM_ALLOC_MINSIZE         (1024*8) 
+#define MM_ALLOC_MINSIZE         (1024*8)
 #define MM_CORE_FILEMODE         (S_IRUSR|S_IWUSR)
 #define MM_CORE_DEFAULT_PAGESIZE (1024*8)
 #define MM_CORE_DEFAULT_FILE     "/tmp/mm.core.%d"  /* %d is PID */
@@ -217,7 +221,7 @@ union semun {
 #define MM_ERR_CORE     2
 #define MM_ERR_SYSTEM   4
 
-/* 
+/*
  * Define a union with types which are likely to have the longest
  * *relevant* CPU-specific memory word alignment restrictions...
  */
@@ -267,7 +271,7 @@ struct mem_core_fd {
     int fd;
 };
 typedef struct mem_core_fd mem_core_fd;
-#define SIZEOF_mem_core_fd (sizeof(mem_core_fd)
+#define SIZEOF_mem_core_fd (sizeof(mem_core_fd))
 #endif
 
 /*
@@ -323,51 +327,51 @@ typedef void MM;
 #endif
 
 /* Global Malloc-Replacement API */
-int     MM_create(size_t size, const char *file);
-int     MM_permission(mode_t mode, uid_t owner, gid_t group);
+int     MM_create(size_t, const char *);
+int     MM_permission(mode_t, uid_t, gid_t);
 void    MM_destroy(void);
-int     MM_lock(mm_lock_mode mode);
+int     MM_lock(mm_lock_mode);
 int     MM_unlock(void);
-void   *MM_malloc(size_t size);
-void   *MM_realloc(void *ptr, size_t size);
-void    MM_free(void *ptr);
-void   *MM_calloc(size_t number, size_t size);
-char   *MM_strdup(const char *str);
-size_t  MM_sizeof(const void *ptr);
+void   *MM_malloc(size_t);
+void   *MM_realloc(void *, size_t);
+void    MM_free(void *);
+void   *MM_calloc(size_t, size_t);
+char   *MM_strdup(const char *);
+size_t  MM_sizeof(const void *);
 size_t  MM_maxsize(void);
 size_t  MM_available(void);
 char   *MM_error(void);
 
 /* Standard Malloc-Style API */
-MM     *mm_create(size_t size, const char *file);
-int     mm_permission(MM *mm, mode_t mode, uid_t owner, gid_t group);
-void    mm_destroy(MM *mm);
-int     mm_lock(MM *mm, mm_lock_mode mode);
-int     mm_unlock(MM *mm);
-void   *mm_malloc(MM *mm, size_t size);
-void   *mm_realloc(MM *mm, void *ptr, size_t size);
-void    mm_free(MM *mm, void *ptr);
-void   *mm_calloc(MM *mm, size_t number, size_t size);
-char   *mm_strdup(MM *mm, const char *str);
-size_t  mm_sizeof(MM *mm, const void *ptr);
+MM     *mm_create(size_t, const char *);
+int     mm_permission(MM *, mode_t, uid_t, gid_t);
+void    mm_destroy(MM *);
+int     mm_lock(MM *, mm_lock_mode);
+int     mm_unlock(MM *);
+void   *mm_malloc(MM *, size_t);
+void   *mm_realloc(MM *, void *, size_t);
+void    mm_free(MM *, void *);
+void   *mm_calloc(MM *, size_t, size_t);
+char   *mm_strdup(MM *, const char *);
+size_t  mm_sizeof(MM *, const void *);
 size_t  mm_maxsize(void);
-size_t  mm_available(MM *mm);
+size_t  mm_available(MM *);
 char   *mm_error(void);
-void    mm_display_info(MM *mm);
+void    mm_display_info(MM *);
 
 /* Low-Level Shared Memory API */
-void   *mm_core_create(size_t size, const char *file);
-int     mm_core_permission(void *core, mode_t mode, uid_t owner, gid_t group);
-void    mm_core_delete(void *core);
-size_t  mm_core_size(const void *core);
-int     mm_core_lock(const void *core, mm_lock_mode mode);
-int     mm_core_unlock(const void *core);
+void   *mm_core_create(size_t, const char *);
+int     mm_core_permission(void *, mode_t, uid_t, gid_t);
+void    mm_core_delete(void *);
+size_t  mm_core_size(const void *);
+int     mm_core_lock(const void *, mm_lock_mode);
+int     mm_core_unlock(const void *);
 size_t  mm_core_maxsegsize(void);
-size_t  mm_core_align2page(size_t size);
-size_t  mm_core_align2word(size_t size);
+size_t  mm_core_align2page(size_t);
+size_t  mm_core_align2word(size_t);
 
 /* Internal Library API */
-void    mm_lib_error_set(unsigned int, const char *str);
+void    mm_lib_error_set(unsigned int, const char *);
 char   *mm_lib_error_get(void);
 int     mm_lib_version(void);
 
