@@ -1,12 +1,13 @@
 /* ====================================================================
- * Copyright (c) 1999-2002 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1999-2003 Ralf S. Engelschall <rse@engelschall.com>
+ * Copyright (c) 1999-2003 The OSSP Project <http://www.ossp.org/>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -118,10 +119,10 @@ static int mm_core_getfdsem(mem_core *mc)
     int fd = -1;
     pid_t pid;
     int i;
-    
+
     pid = getpid();
-    for (i = 0; i < MM_MAXCHILD && 
-                mc->mc_fdsem[i].pid != 0 && 
+    for (i = 0; i < MM_MAXCHILD &&
+                mc->mc_fdsem[i].pid != 0 &&
                 mc->mc_fdsem[i].fd != -1; i++) {
         if (mc->mc_fdsem[i].pid == pid) {
             fd = mc->mc_fdsem[i].fd;
@@ -130,6 +131,9 @@ static int mm_core_getfdsem(mem_core *mc)
     }
     if (fd == -1 && i < MM_MAXCHILD) {
         fd = open(mc->mc_fnsem, O_WRONLY, MM_CORE_FILEMODE);
+#if defined(F_SETFD) && defined(FD_CLOEXEC)
+        fcntl(fd, F_SETFD, FD_CLOEXEC);
+#endif
         mc->mc_fdsem[i].pid = getpid();
         mc->mc_fdsem[i].fd  = fd;
     }
@@ -236,7 +240,7 @@ void *mm_core_create(size_t usersize, const char *file)
 #endif
 
 #if defined(MM_SHMT_MMANON)
-    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE, 
+    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE,
                              MAP_ANON|MAP_SHARED, -1, 0)) == (void *)MAP_FAILED)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to memory map anonymous area");
 #endif /* MM_SHMT_MMANON */
@@ -254,7 +258,7 @@ void *mm_core_create(size_t usersize, const char *file)
     if (ftruncate(fdmem, mm_core_mapoffset+size) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to truncate tempfile");
     write(fdmem, &zero, sizeof(zero));
-    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE, 
+    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE,
                              MAP_SHARED, fdmem, mm_core_mapoffset)) == (void *)MAP_FAILED)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to memory map tempfile");
     shm_unlink(fnmem);
@@ -264,10 +268,14 @@ void *mm_core_create(size_t usersize, const char *file)
 #if defined(MM_SHMT_MMZERO)
     if ((fdmem = open("/dev/zero", O_RDWR, MM_CORE_FILEMODE)) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to open /dev/zero");
+#if defined(F_SETFD) && defined(FD_CLOEXEC)
+    if (fcntl(fdmem, F_SETFD, FD_CLOEXEC) == -1)
+        FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to set close-on-exec flag");
+#endif
     if (lseek(fdmem, mm_core_mapoffset+size, SEEK_SET) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to seek in /dev/zero");
     write(fdmem, &zero, sizeof(zero));
-    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE, 
+    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE,
                              MAP_SHARED, fdmem, mm_core_mapoffset)) == (void *)MAP_FAILED)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to memory map /dev/zero");
     mm_core_mapoffset += size;
@@ -277,10 +285,14 @@ void *mm_core_create(size_t usersize, const char *file)
     unlink(fnmem);
     if ((fdmem = open(fnmem, O_RDWR|O_CREAT|O_EXCL, MM_CORE_FILEMODE)) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to open memory file");
+#if defined(F_SETFD) && defined(FD_CLOEXEC)
+    if (fcntl(fdmem, F_SETFD, FD_CLOEXEC) == -1)
+        FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to set close-on-exec flag");
+#endif
     if (ftruncate(fdmem, mm_core_mapoffset+size) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to truncate memory file");
     write(fdmem, &zero, sizeof(zero));
-    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE, 
+    if ((area = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE,
                              MAP_SHARED, fdmem, mm_core_mapoffset)) == (void *)MAP_FAILED)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to memory map memory file");
     mm_core_mapoffset += size;
@@ -305,12 +317,20 @@ void *mm_core_create(size_t usersize, const char *file)
     unlink(fnsem);
     if ((fdsem = open(fnsem, O_RDWR|O_CREAT|O_EXCL, MM_CORE_FILEMODE)) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to open semaphore file");
+#if defined(F_SETFD) && defined(FD_CLOEXEC)
+    if (fcntl(fdsem, F_SETFD, FD_CLOEXEC) == -1)
+        FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to set close-on-exec flag");
+#endif
 #endif /* MM_SEMT_FLOCK */
 
 #if defined(MM_SEMT_FCNTL)
     unlink(fnsem);
     if ((fdsem = open(fnsem, O_RDWR|O_CREAT|O_EXCL, MM_CORE_FILEMODE)) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to open semaphore file");
+#if defined(F_SETFD) && defined(FD_CLOEXEC)
+    if (fcntl(fdsem, F_SETFD, FD_CLOEXEC) == -1)
+        FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to set close-on-exec flag");
+#endif
 #endif /* MM_SEMT_FCNTL */
 
 #if defined(MM_SEMT_IPCSEM)
@@ -590,7 +610,7 @@ int mm_core_lock(const void *core, mm_lock_mode mode)
         }
     }
 #endif
- 
+
     if (rc < 0) {
         ERR(MM_ERR_CORE|MM_ERR_SYSTEM, "Failed to lock");
         rc = FALSE;
